@@ -9,8 +9,11 @@
 
 #include <jni.h>
 #include <glib.h>
+#include <gdk/gdk.h>
 #include <jg_jnu.h>
 #include "gtk_java.h"
+
+#include "org_gnu_glib_Error.h"
 #ifdef __cplusplus
 extern "C" 
 {
