@@ -1,7 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
+ * Copyright 1998-2006 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
@@ -257,9 +257,14 @@ JNIEXPORT void JNICALL Java_org_gnu_glib_Value_g_1value_1set_1long
     GValue *value_g;
 	
     value_g = (GValue *)getPointerFromHandle(env, value);
+   
+    /*
+     * Java's longs are defined as 64 bit wide signed integer values
+     * This corresponds to gint64 in glib/gobject terms.
+     */
 
     gdk_threads_enter();
-    g_value_set_long (value_g, (glong)vLong);
+    g_value_set_int64(value_g, (gint64) vLong);
     gdk_threads_leave();
 }
 
